.. image:: https://travis-ci.org/tencentyun/cos_migrate_tool.svg?branch=master
    :target: https://travis-ci.org/tencentyun/cos_migrate_tool
    
.. image:: https://badge.fury.io/py/cos_migrate_tool.svg
    :target: https://badge.fury.io/py/cos_migrate_tool
    
.. image:: https://img.shields.io/github/release/tencentyun/cos_migrate_tool.svg
    :target: https://github.com/tencentyun/cos_migrate_tool
    
.. image:: https://img.shields.io/pypi/dm/cos_migrate_tool.svg   
    :target: https://pypi.python.org/pypi/cos_migrate_tool
    
    
cos_migrate_tool
##########################

A simple tool for migrating data between object storage services.

INSTALL
-----------

use pip ::

    pip install -U cos_migrate_tool


HOW TO USE
---------------

as following ::

    cos_migrate_tool -h
    cos_migrate_tool -c /path/to/your/conf


ISSUE
---------------

send emails to liuchang0812#gmail.com or post an issue

TODO
---------------

1. add overwrite option
2. add retry option
3. add more logging


LICENSE
----------

MIT
